==> polyv-java-live-sdk-1.2.0-sources.jar: net/polyv/live/v2/entity/channel/web/interact/LiveUpdateChannelDonateRequest.java <==
package net.polyv.live.v2.entity.channel.web.interact;

import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import net.polyv.common.v1.validator.constraints.NotNull;
import net.polyv.live.v1.entity.LiveCommonRequest;

/**
 * 修改频道礼物打赏设置请求实体
 * @author jiangyifan
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@ApiModel("修改频道礼物打赏设置请求实体")
public class LiveUpdateChannelDonateRequest extends LiveCommonRequest {
    /**
     * 频道号
     */
    @ApiModelProperty(name = "channelId", value = "频道号", required = true)
    @NotNull(message = "属性channelId不能为空")
    private String channelId;
    
    /**
     * 礼物打赏开关，Y：开启，N：关闭
     */
    @ApiModelProperty(name = "donateGiftEnabled", value = "礼物打赏开关，Y：开启，N：关闭", required = false)
    private String donateGiftEnabled;
    
    /**
     * 礼物打赏（现金支付或积分支付）
     */
    @ApiModelProperty(name = "giftDonate", value = "礼物打赏（现金支付或积分支付）【详见ChannelGiftDonate字段说明】", required = false)
    private LiveUpdateChannelDonateRequest.ChannelGiftDonate giftDonate;
    
    @Data
    @Accessors(chain = true)
    @ApiModel("礼物打赏（现金支付或积分支付）")
    public static class ChannelGiftDonate {
        /**
         * 支付方式，CASH：现金支付，POINT：积分支付
         */
        @ApiModelProperty(name = "payWay", value = "支付方式，CASH：现金支付，POINT：积分支付", required = false)
        private String payWay;
        
        /**
         * 现金单位
         */
        @ApiModelProperty(name = "cashUnit", value = "现金单位", required = false)
        private String cashUnit;
        
        /**
         * 积分单位
         */
        @ApiModelProperty(name = "pointUnit", value = "积分单位", required = false)
        private String pointUnit;
        
        /**
         * 现金支付列表
         */
        @ApiModelProperty(name = "cashPays", value = "现金支付列表【详见ChannelGift字段说明】", required = false)
        private List<LiveUpdateChannelDonateRequest.ChannelGift> cashPays;
        
        /**
         * 积分支付列表
         */
        @ApiModelProperty(name = "pointPays", value = "积分支付列表【详见ChannelGift字段说明】", required = false)
        private List<LiveUpdateChannelDonateRequest.ChannelGift> pointPays;
    }
    
    @Data
    @Accessors(chain = true)
    @ApiModel("礼物列表")
    public static class ChannelGift {
        
        /**
         * 礼物名称
         */
        @ApiModelProperty(name = "name", value = "礼物名称", required = false)
        private String name;
        
        /**
         * 礼物图片地址
         */
        @ApiModelProperty(name = "img", value = "礼物图片地址", required = false)
        private String img;
        
        /**
         * 礼物价格
         */
        @ApiModelProperty(name = "price", value = "礼物价格", required = false)
        private Float price;
        
        /**
         * 开关，Y：开启，N：关闭
         */
        @ApiModelProperty(name = "enabled", value = "开关，Y：开启，N：关闭", required = false)
        private String enabled;
    }
    
}

==> polyv-java-live-sdk-2.1.14-sources.jar: net/polyv/live/v2/entity/channel/web/interact/LiveUpdateChannelDonateRequest.java <==
package net.polyv.live.v2.entity.channel.web.interact;

import java.util.List;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import net.polyv.common.v1.validator.constraints.NotNull;
import net.polyv.live.v1.entity.LiveCommonRequest;

/**
 * 修改频道礼物打赏设置请求实体
 * @author jiangyifan
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@ApiModel("修改频道礼物打赏设置请求实体")
public class LiveUpdateChannelDonateRequest extends LiveCommonRequest {
    /**
     * 频道号
     */
    @ApiModelProperty(name = "channelId", value = "频道号", required = true)
    @NotNull(message = "属性channelId不能为空")
    private String channelId;
    
    /**
     * 礼物打赏开关，Y：开启，N：关闭
     */
    @ApiModelProperty(name = "donateGiftEnabled", value = "礼物打赏开关，Y：开启，N：关闭", required = false)
    private String donateGiftEnabled;
    
    /**
     * 礼物打赏（现金支付或积分支付）
     */
    @ApiModelProperty(name = "giftDonate", value = "礼物打赏（现金支付或积分支付）", required = false)
    private LiveUpdateChannelDonateRequest.ChannelGiftDonate giftDonate;
    
    @Data
    @Accessors(chain = true)
    @ApiModel("礼物打赏（现金支付或积分支付）")
    public static class ChannelGiftDonate {
        /**
         * 支付方式，CASH：现金支付，POINT：积分支付
         */
        @ApiModelProperty(name = "payWay", value = "支付方式，CASH：现金支付，POINT：积分支付", required = false)
        private String payWay;
        
        /**
         * 现金单位
         */
        @ApiModelProperty(name = "cashUnit", value = "现金单位", required = false)
        private String cashUnit;
        
        /**
         * 积分单位
         */
        @ApiModelProperty(name = "pointUnit", value = "积分单位", required = false)
        private String pointUnit;
        
        /**
         * 现金支付列表
         */
        @ApiModelProperty(name = "cashPays", value = "现金支付列表", required = false)
        private List<LiveUpdateChannelDonateRequest.ChannelGift> cashPays;
        
        /**
         * 积分支付列表
         */
        @ApiModelProperty(name = "pointPays", value = "积分支付列表", required = false)
        private List<LiveUpdateChannelDonateRequest.ChannelGift> pointPays;
    }
    
    @Data
    @Accessors(chain = true)
    @ApiModel("礼物列表")
    public static class ChannelGift {
        
        /**
         * 礼物名称
         */
        @ApiModelProperty(name = "name", value = "礼物名称", required = false)
        private String name;
        
        /**
         * 礼物图片地址
         */
        @ApiModelProperty(name = "img", value = "礼物图片地址", required = false)
        private String img;
        
        /**
         * 礼物价格
         */
        @ApiModelProperty(name = "price", value = "礼物价格", required = false)
        private Float price;
        
        /**
         * 开关，Y：开启，N：关闭
         */
        @ApiModelProperty(name = "enabled", value = "开关，Y：开启，N：关闭", required = false)
        private String enabled;
    }
    
}
